/**
 * 
 */
package org.colcon.web.client.item;

import java.util.HashMap;
import java.util.Map;

import org.colcon.burocrat.api.client.IClient;
import org.colcon.burocrat.api.model.ICommand;
import org.colcon.burocrat.api.model.IItem;
import org.colcon.burocrat.api.model.IResponse;
import org.colcon.burocrat.client.item.ItemPage;
import org.colcon.burocrat.client.vis.PieChartPanel;
import org.colcon.burocrat.model.Arg;
import org.colcon.burocrat.model.Cmd;
import org.colcon.burocrat.model.Command;
import org.colcon.burocrat.model.Constants;
import org.colcon.burocrat.model.Item;
import org.colcon.burocrat.model.ItemType;
import org.colcon.burocrat.model.Model;
import org.colcon.web.model.AppArg;
import org.colcon.web.model.AppItemType;

import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.event.dom.client.ClickHandler;
import com.google.gwt.user.client.rpc.AsyncCallback;
import com.google.gwt.user.client.ui.Button;
import com.google.gwt.user.client.ui.HTML;
import com.google.gwt.user.client.ui.PopupPanel;
import com.google.gwt.user.client.ui.RadioButton;
import com.google.gwt.user.client.ui.VerticalPanel;
import com.google.gwt.user.client.ui.Widget;

/**
 * @author Jesse
 *
 */
public class VotePage extends ItemPage implements ClickHandler
{
	private RadioButton[] radioButtons;
	private Button voteButton;
	
	public VotePage(IClient client, IItem item)
	{
		super(client, item);
	
	}

	public Widget buildPage()
	{
		final VerticalPanel panel = new VerticalPanel();
		
		String subject = getItem().getArg(Arg.SUBJECT);
		String choices = getItem().getArg(AppArg.CHOICES);
		
		panel.add(new HTML("<h1>" + subject + "</h1>"));
		panel.add(new HTML("<b>Choices</b>"));
		
		String[] choiceArray = Model.instance.parser().parseArgArray(choices);
		radioButtons = new RadioButton[choiceArray.length];
		
		for(int i = 0; i < choiceArray.length; i++)
		{
			radioButtons[i] = new RadioButton("choices", choiceArray[i]);
			panel.add(radioButtons[i]);
		}
		
		voteButton = new Button("Vote");
		voteButton.addClickHandler(this);
		panel.add(voteButton);
		
		panel.add(new HTML("<h1>Results</h1>"));
		
		ICommand command = new Command(
				Arg.CMD.put(Cmd.QUERY_LINKS),
				Arg.TARGET.put(getItem().getPath()),
				Arg.FILTERS.put(Arg.TYPE.put(AppItemType.BALLOT))
		);
		
		final VerticalPanel resultsPanel = new VerticalPanel();
		
		resultsPanel.add(getClient().widgets().loading());
		
		panel.add(resultsPanel);
		
		getClient().sendRequest(command, new AsyncCallback<IResponse>()
		{
			public void onFailure(Throwable caught) 
			{
				resultsPanel.clear();
				resultsPanel.add(new HTML(caught.getLocalizedMessage()));
			}

			public void onSuccess(IResponse result) 
			{
				IItem[] ballots = (IItem[]) result.getObject();
				
				Map<String, Integer> results = new HashMap<String, Integer>();
				
				for(IItem ballot : ballots)
				{
					String value = ballot.getArg(Arg.VALUE);
					
					if(results.containsKey(value))
						results.put(value, results.get(value) + 1);
					else
						results.put(value, 1);
				}
				
				resultsPanel.clear();
				resultsPanel.add(new PieChartPanel(getClient(), results));
			}
		});
		
		return panel;
	}
	
	private String getSelectedValue()
	{
		for(RadioButton button : radioButtons)
			if(button.getValue())
				return button.getText();
		
		return null;
	}

	public void onClick(ClickEvent event) 
	{
		String value = getSelectedValue();
		
		if(value == null)
		{
			PopupPanel popup = new PopupPanel();
			popup.add(new HTML("invalid input"));
			popup.center();
			popup.show();
			return;
		}
		
		IItem ballot = new Item(
				Arg.TYPE.put(AppItemType.BALLOT),
				Arg.SOURCE.put(ItemType.USER.getInstancePath(Constants.GUEST)),
				Arg.TARGET.put(getItem().getPath()),
				Arg.VALUE.put(value)
		);
		
		ICommand command = new Command(
				Arg.CMD.put(Cmd.POST),
				Arg.ITEM.put(ballot)
		);
		
		getClient().sendRequest(command, new AsyncCallback<IResponse>()
		{
			public void onFailure(Throwable caught) 
			{
				PopupPanel popup = new PopupPanel();
				popup.add(new HTML(caught.getLocalizedMessage()));
				popup.center();
				popup.show();
			}

			public void onSuccess(IResponse result) 
			{
				refresh();
			}
		});
	}
}
