/**
 * 
 */
package org.colcon.web.client.pages;

import org.colcon.burocrat.api.client.IClient;
import org.colcon.burocrat.api.model.IArg;
import org.colcon.burocrat.api.model.ICommand;
import org.colcon.burocrat.api.model.IItem;
import org.colcon.burocrat.api.model.IResponse;
import org.colcon.burocrat.client.list.BurocratList;
import org.colcon.burocrat.client.ui.BurocratPage;
import org.colcon.burocrat.model.Arg;
import org.colcon.burocrat.model.Cmd;
import org.colcon.burocrat.model.Command;
import org.colcon.burocrat.model.Item;
import org.colcon.web.model.AppArg;
import org.colcon.web.model.AppItemType;

import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.event.dom.client.ClickHandler;
import com.google.gwt.user.client.rpc.AsyncCallback;
import com.google.gwt.user.client.ui.Button;
import com.google.gwt.user.client.ui.Grid;
import com.google.gwt.user.client.ui.HTML;
import com.google.gwt.user.client.ui.Label;
import com.google.gwt.user.client.ui.PopupPanel;
import com.google.gwt.user.client.ui.TextBox;
import com.google.gwt.user.client.ui.VerticalPanel;

/**
 * @author Dan Vegeto
 *
 */
public class VotesPage extends BurocratPage implements ClickHandler
{
	private TextBox subjectBox, choicesBox;
	private Button postButton;
	
	public VotesPage(IClient client)
	{
		super(client);
	}
	
	public void init(IResponse data)
	{
		super.init(data);
		
		VerticalPanel panel = new VerticalPanel();
		
		panel.add(new HTML("<h1>Public Votes</h1>"));
		
		Grid grid = new Grid(3, 2);
		
		subjectBox = new TextBox();
		grid.setWidget(0, 0, new Label("Subject"));
		grid.setWidget(0, 1, subjectBox);
		
		choicesBox = new TextBox();
		grid.setWidget(1, 0, new HTML("Choices<br>(A, B, C)"));
		grid.setWidget(1, 1, choicesBox);
		
		postButton = new Button("Create Vote");
		postButton.addClickHandler(this);
		grid.setWidget(2, 1, postButton);
		
		panel.add(grid);
		
		panel.add(new BurocratList(getClient(), AppItemType.VOTE.plural(), new IArg[]{Arg.SUBJECT}));
		
		add(panel);
	}

	public void onClick(ClickEvent event) 
	{
		String subject = subjectBox.getValue();
		String choices = choicesBox.getValue();
		
		if(subject.isEmpty() || choices.isEmpty())
		{
			PopupPanel popup = new PopupPanel();
			popup.add(new HTML("invalid input"));
			popup.center();
			popup.show();
			return;
		}
		
		IItem vote = new Item(
				Arg.TYPE.put(AppItemType.VOTE),
				Arg.PARENT.put(AppItemType.VOTE.plural()),
				Arg.SUBJECT.put(subject),
				AppArg.CHOICES.put(choices)
		);
		
		ICommand command = new Command(
				Arg.CMD.put(Cmd.POST),
				Arg.ITEM.put(vote)
		);
		
		getClient().sendRequest(command, new AsyncCallback<IResponse>()
		{
			public void onFailure(Throwable caught) 
			{
				PopupPanel popup = new PopupPanel();
				popup.add(new HTML(caught.getLocalizedMessage()));
				popup.center();
				popup.show();
			}

			public void onSuccess(IResponse result) 
			{
				refresh();
			}
		});
	}
}
