package org.colcon.web.client.ui;

import java.util.HashMap;
import java.util.Map;

import org.colcon.burocrat.api.client.IClient;
import org.colcon.burocrat.api.model.IArg;
import org.colcon.burocrat.api.model.ICommand;
import org.colcon.burocrat.api.model.IResponse;
import org.colcon.burocrat.client.CSS;
import org.colcon.burocrat.client.PageImpl;
import org.colcon.burocrat.client.ui.BurocratPanel;
import org.colcon.burocrat.model.Arg;
import org.colcon.burocrat.model.Cmd;
import org.colcon.burocrat.model.Command;
import org.colcon.burocrat.model.Model;

import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.event.dom.client.ClickHandler;
import com.google.gwt.event.dom.client.FocusEvent;
import com.google.gwt.event.dom.client.FocusHandler;
import com.google.gwt.user.client.rpc.AsyncCallback;
import com.google.gwt.user.client.ui.Button;
import com.google.gwt.user.client.ui.HTML;
import com.google.gwt.user.client.ui.HasHorizontalAlignment;
import com.google.gwt.user.client.ui.HorizontalPanel;
import com.google.gwt.user.client.ui.PasswordTextBox;
import com.google.gwt.user.client.ui.PopupPanel;
import com.google.gwt.user.client.ui.TextBox;
import com.google.gwt.user.client.ui.VerticalPanel;

public class LoginPanel extends BurocratPanel implements ClickHandler, FocusHandler
{
	private TextBox username;
	private PasswordTextBox password;
	private Button login, register;
	
	public LoginPanel(IClient client) 
	{
		super(client);
	}

	public void init(IResponse data) 
	{
		VerticalPanel rightPanel = new VerticalPanel();
		rightPanel.setWidth("100%");
		rightPanel.setHorizontalAlignment(HasHorizontalAlignment.ALIGN_RIGHT);
		rightPanel.setVerticalAlignment(VerticalPanel.ALIGN_MIDDLE);
		
		VerticalPanel leftPanel = new VerticalPanel();
		leftPanel.setWidth("100%");
		leftPanel.setHorizontalAlignment(HasHorizontalAlignment.ALIGN_RIGHT);
		leftPanel.setVerticalAlignment(VerticalPanel.ALIGN_MIDDLE);
		
		HorizontalPanel panel = new HorizontalPanel();
		panel.setHorizontalAlignment(HasHorizontalAlignment.ALIGN_RIGHT);
		
		username = new TextBox();
		username.setStyleName(CSS.USER_PANEL_INPUT.getStyle());
		username.setText("Username");
		username.addFocusHandler(this);
		
		password = new PasswordTextBox();
		password.setStyleName(CSS.USER_PANEL_INPUT.getStyle());
		password.setText("Password");
		password.addFocusHandler(this);
		
		login = new Button("login");
		login.setStyleName(CSS.USER_PANEL_BUTTON.getStyle());
		login.addClickHandler(this);
		
		register = new Button("register");
		register.setStyleName(CSS.USER_PANEL_BUTTON.getStyle());
		register.addClickHandler(this);
		
		leftPanel.add(username);
		leftPanel.add(password);
		rightPanel.add(login);
		rightPanel.add(register);
		
		panel.add(leftPanel);
		panel.add(rightPanel);
		add(panel);
	}

	public void onClick(ClickEvent event) 
	{
		if(event.getSource().equals(login))
		{
			final String idStr = username.getText();
			final String passwordStr = password.getText();
			
			final PopupPanel popup = new PopupPanel();
			popup.add(getClient().widgets().loading());
			popup.center();
			
			ICommand command = new Command(
					Arg.CMD.put(Cmd.AUTHENTICATE),
					Arg.ID.put(idStr), 
					Arg.PASSWORD.put(passwordStr));
			
			getClient().sendRequest(command, new AsyncCallback<IResponse>()
			{
				public void onFailure(Throwable caught) 
				{
					popup.clear();
					popup.add(new HTML(caught.getLocalizedMessage()));
				}

				public void onSuccess(IResponse result) 
				{
					if(result.isSuccess())
					{
						getClient().login(idStr, passwordStr);
						getClient().refresh();
						popup.hide();
					}
					else
					{
						popup.clear();
						popup.add(new HTML("Login failed"));
					}
				}
			});
		}
		else if(event.getSource().equals(register))
		{
			Map<IArg, String> map = new HashMap<IArg, String>();
			map.put(Arg.CMD, Cmd.REGISTER.name());
			String token = PageImpl.FORM.name() + '?' + Model.instance.parser().composeArgs(map);
			
			getClient().show(token);
		}
	}

	@Override
	public void onFocus(FocusEvent event)
	{
		if(event.getSource().equals(username))
		{
			if(username.getText() == "Username")
				username.setText("");
			else
				username.selectAll();
				
		}
		else if(event.getSource().equals(password))
		{
			if(password.getText() == "Password")
				password.setText("");
			else
				password.selectAll();
		}
	}
}
