/**
 * 
 */
package org.colcon.web.client.ui;

import org.colcon.burocrat.api.client.IClient;
import org.colcon.burocrat.api.model.IResponse;
import org.colcon.burocrat.client.ui.BurocratPanel;
import org.colcon.web.client.ColConCSS;

import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.event.dom.client.ClickHandler;
import com.google.gwt.event.logical.shared.CloseEvent;
import com.google.gwt.event.logical.shared.CloseHandler;
import com.google.gwt.user.client.ui.HorizontalPanel;
import com.google.gwt.user.client.ui.Label;
import com.google.gwt.user.client.ui.PopupPanel;

/**
 * @author Jesse Freitas
 *
 */
public class NotificationPanel extends BurocratPanel implements ClickHandler, CloseHandler<PopupPanel>
{

	private Label news = new Label();
	private Label groups = new Label();
	private Label votes = new Label();
	
	private PopupPanel panel;
	private int expanded = -1;
	
	/**
	 * @param client
	 */
	public NotificationPanel(IClient client)
	{
		super(client);
	}

	/**
	 * @see org.colcon.burocrat.client.ui.BurocratPanel#init(org.colcon.burocrat.api.model.IResponse)
	 */
	@Override
	public void init(IResponse data)
	{
		
		news.setStyleName(ColConCSS.NEWS_ICON.getStyle());
		groups.setStyleName(ColConCSS.GROUPS_ICON.getStyle());
		votes.setStyleName(ColConCSS.VOTES_ICON.getStyle());
		HorizontalPanel notes = new HorizontalPanel();
		
		news.addClickHandler(this);
		groups.addClickHandler(this);
		votes.addClickHandler(this);
		notes.add(groups);
		notes.add(news);
		notes.add(votes);
		add(notes);
	}
	public void onClick(ClickEvent event)
	{
		if(panel != null)
			panel.hide();
		panel = buildPopup(event);
		news.removeStyleName(ColConCSS.NEWS_ICON_SELECTED.getStyle());
		groups.removeStyleName(ColConCSS.GROUPS_ICON_SELECTED.getStyle());
		votes.removeStyleName(ColConCSS.VOTES_ICON_SELECTED.getStyle());
		if(event.getSource() == news && expanded != 0){
			news.addStyleName(ColConCSS.NEWS_ICON_SELECTED.getStyle());
			panel.setPopupPosition(news.getAbsoluteLeft(), news.getAbsoluteTop() + news.getOffsetHeight());
			panel.show();
			expanded = 0;
		}
		else if(event.getSource() == groups && expanded != 1){
			groups.addStyleName(ColConCSS.GROUPS_ICON_SELECTED.getStyle());
			panel.setPopupPosition(groups.getAbsoluteLeft(), groups.getAbsoluteTop() + groups.getOffsetHeight());
			panel.show();
			expanded = 1;
		}
		else if(event.getSource() == votes && expanded != 2){
			votes.addStyleName(ColConCSS.VOTES_ICON_SELECTED.getStyle());
			panel.setPopupPosition(votes.getAbsoluteLeft(), votes.getAbsoluteTop() + votes.getOffsetHeight());
			panel.show();
			expanded = 2;
		}
		else{
			expanded = -1;
		}
	}

	private PopupPanel buildPopup(ClickEvent event)
	{
		PopupPanel panel = new PopupPanel(true);
		panel.setStyleName(ColConCSS.NOTE_POPUP.getStyle());
		panel.addCloseHandler(this);
		if(event.getSource().equals(news)){
			Label header = new Label("News");
			header.setStyleName(ColConCSS.PAGE_SUBTITLE.getStyle());
			panel.add(header);
		}
		if(event.getSource().equals(groups)){
			Label header = new Label("Groups");
			header.setStyleName(ColConCSS.PAGE_SUBTITLE.getStyle());
			panel.add(header);
		}
		if(event.getSource().equals(votes)){
			Label header = new Label("Active Votes");
			header.setStyleName(ColConCSS.PAGE_SUBTITLE.getStyle());
			panel.add(header);
		}
		return panel;
	}

	@Override
	public void onClose(CloseEvent<PopupPanel> event)
	{
		news.removeStyleName(ColConCSS.NEWS_ICON_SELECTED.getStyle());
		groups.removeStyleName(ColConCSS.GROUPS_ICON_SELECTED.getStyle());
		votes.removeStyleName(ColConCSS.VOTES_ICON_SELECTED.getStyle());
	}

}
