package org.colcon.web.model;

import java.util.Arrays;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import org.colcon.burocrat.api.model.IArg;
import org.colcon.burocrat.api.model.IArgList;
import org.colcon.burocrat.api.model.ICmd;
import org.colcon.burocrat.api.model.IFlag;
import org.colcon.burocrat.api.model.IResponse;
import org.colcon.burocrat.model.Arg;
import org.colcon.burocrat.model.ArgList;

public enum AppCmd implements ICmd
{
	TEST("a test command");
	
	private String description;
	private IArgList argList;
	private Set<IFlag> flags;
	
	private AppCmd(String description)
	{
		this(description, new ArgList(), new IFlag[0]);
	}
	
	private AppCmd(String description, IArgList argList)
	{
		this(description, argList, new IFlag[0]);
	}
	
	private AppCmd(String description, IArgList argList, IFlag[] flags)
	{
		this.description = description;
		this.argList = argList;
		
		this.flags = new HashSet<IFlag>();
		this.flags.addAll(Arrays.asList(flags));
	}
	
	public String description()
	{
		return description;
	}
	
	public IArgList argList()
	{
		return argList;
	}
	
	public IFlag[] flags()
	{
		return flags.toArray(new IFlag[0]);
	}
	
	public boolean hasFlag(IFlag flag)
	{
		return flags.contains(flag);
	}
	
	public IResponse validate(String agent, Map<IArg, String> args)
	{
		return argList().validate(args);
	}
	
	public String getNews(String agent, Map<IArg, String> args)
	{
		return "#" + agent + " executed  command '" + name() + "'";
	}
	
	public String getHelpString()
	{
		String str = name().toLowerCase();
		
		while(str.length() < 15)
			str += ' ';
		
		str += description();
		
		return str;
	}
	
	public Map<IArg, String> withArgs(Object... values)
	{
		Map<IArg, String> map = argList().withArgs(values);
		
		map.put(Arg.CMD, name());
		
		return map;
	}
	
	public static ICmd[] getValues()
	{
		return (ICmd[])values();
	}
}
