package org.colcon.web.server;

import org.colcon.burocrat.api.model.IArg;
import org.colcon.burocrat.api.model.IItem;
import org.colcon.burocrat.api.model.IItemType;
import org.colcon.burocrat.api.model.ILink;
import org.colcon.burocrat.api.server.IItemTypeImpl;
import org.colcon.burocrat.client.PageImpl;
import org.colcon.burocrat.model.Arg;
import org.colcon.burocrat.model.ArgFlag;
import org.colcon.burocrat.model.Cmd;
import org.colcon.burocrat.model.Item;
import org.colcon.burocrat.model.ItemType;
import org.colcon.burocrat.model.Link;
import org.colcon.burocrat.model.Model;
import org.colcon.burocrat.server.Server;
import org.colcon.web.model.AppConstants;

public enum AppItemTypeImpl implements IItemTypeImpl
{
	USER
	{
		public void init(IItem instance)
		{
			// confirmation code initialized in ItemType.USER
			String confirmationCode = instance.getArg(Arg.CONFIRMATION_CODE);
			
			// code encrypted in parent init method
			super.init(instance);
			
			String id = instance.getArg(Arg.ID);
			String email = instance.getArg(Arg.EMAIL);
			String subject = "email confirmation";
			
			ILink link = new Link(PageImpl.FORM.name(),
					Arg.CMD.put(Cmd.CONFIRM_EMAIL.name()),
					Arg.ID.put(id),
					Arg.CONFIRMATION_CODE.put(confirmationCode));
			
			String url = link.toURLString(AppConstants.URL);
			
			String text = 
				"<p>Thank you for registering on Collective Congress!</p>" +
				"<p>id: " + id +
				"<p>confirmation code: " + confirmationCode + "</p>" +
				"<p>Please use the following link to confirm your email address: " + url + "</p><br>";
			
			Server.instance.emailer().send(email, subject, text);
		}
	};
	
	public IItemTypeImpl getParent()
	{
		IItemType type = Model.instance.getItemType(name());
		
		if(type == null)
			return null;
		
		if(type.parent() == null)
			return null;
		
		return Server.instance.getItemTypeImpl(type.parent().name());
	}
	
	public boolean validate(IItem instance)
	{
		if(getParent() != null)
			return getParent().validate(instance);
		
		return instance != null && instance.getType() != null && instance.getPath() != null;
	}
	
	public void init(IItem instance)
	{
		if(instance.getId() == null)
			instance.setArg(Arg.ID, generateId(instance));
		
		// encrypt args with ENCRYPTED flag
		for(IArg arg : instance.getArgKeys())
		{
			if(arg.hasFlag(ArgFlag.ENCRYPTED))
			{
				String plain = instance.getArg(arg);
				String encrypted = Server.instance.encryptor().encrypt(plain);
				instance.setArg(arg, encrypted);
			}
		}
		
		// post subcontainers
		for(IItemType type : instance.getType().getAllContainerTypes())
		{
			IItem container = new Item(
					Arg.TYPE.put(ItemType.CONTAINER),
					Arg.PARENT.put(instance.getPath()),
					Arg.ID.put(type.plural()));
			
			Server.instance.post(container);
		}
	}
	
	public String generateId(IItem instance)
	{
		if(getParent() != null)
			return getParent().generateId(instance);
		
		String id = (int)(Math.random() * 10) + "";
		instance.setArg(Arg.ID, id);
		
		while(Server.instance.get(instance.getPath()) != null)
		{
			id += (int)(Math.random() * 10) + "";
			instance.setArg(Arg.ID, id);
		}
		
		return id;
	}
	
	public static IItemTypeImpl[] getValues()
	{
		return (IItemTypeImpl[])values();
	}
}
