package org.colcon.burocrat.client;

import org.colcon.burocrat.api.client.IClient;
import org.colcon.burocrat.api.model.IArg;
import org.colcon.burocrat.client.ui.BurocratPanel;

import com.google.gwt.event.dom.client.ChangeHandler;
import com.google.gwt.event.dom.client.KeyUpEvent;
import com.google.gwt.event.dom.client.KeyUpHandler;
import com.google.gwt.user.client.Event;

/**
 * This is the superclass for all input GUI components (text boxes, radio buttons, etc.) in a BurocratForm, 
 * which allows users to enter data values for a given argument
 * 
 * @author Dan Vegeto
 *
 */
public abstract class BurocratField extends BurocratPanel implements KeyUpHandler
{
	private IArg arg;
	private ChangeHandler handler;
	
	public BurocratField(IClient client, IArg arg) 
	{
		super(client);
		
		this.arg = arg;
		
		sinkEvents(Event.ONKEYUP);
		addHandler(this, KeyUpEvent.getType());
	}

	public IArg getArg()
	{
		return arg;
	}
	
	public ChangeHandler getChangeHandler()
	{
		return handler;
	}
	
	public void addChangeHandler(ChangeHandler handler)
	{
		this.handler = handler; 
	}
	
	public void onKeyUp(KeyUpEvent event) 
	{
		getChangeHandler().onChange(null);
	}
	
	public abstract String getValue();
	public abstract void setValue(String value);
}
