package org.colcon.burocrat.client;

import org.colcon.burocrat.api.client.IClient;
import org.colcon.burocrat.api.client.IFieldTypeImpl;
import org.colcon.burocrat.api.model.IArg;
import org.colcon.burocrat.client.form.ListBoxField;
import org.colcon.burocrat.client.form.PasswordBoxField;
import org.colcon.burocrat.client.form.RadioSelectionField;
import org.colcon.burocrat.client.form.TextAreaField;
import org.colcon.burocrat.client.form.TextBoxField;

/**
 * These are implementations of input GUI components for the FieldTypes with the same names
 * 
 * @author Dan Vegeto
 *
 */
public enum FieldTypeImpl implements IFieldTypeImpl 
{
	TEXT_BOX
	{
		public BurocratField buildField(IClient client, IArg arg)
		{
			return new TextBoxField(client, arg);
		}
	},
	
	TEXT_AREA
	{
		public BurocratField buildField(IClient client, IArg arg)
		{
			return new TextAreaField(client, arg);
		}
	},
	
	PASSWORD_BOX
	{
		public BurocratField buildField(IClient client, IArg arg)
		{
			return new PasswordBoxField(client, arg);
		}
	},
	
	LIST_BOX
	{
		public BurocratField buildField(IClient client, IArg arg)
		{
			return new ListBoxField(client, arg);
		}
	},
	
	RADIO_BUTTONS
	{
		public BurocratField buildField(IClient client, IArg arg)
		{
			return new RadioSelectionField(client, arg);
		}
	},
	
	FORM
	{
		public BurocratField buildField(IClient client, IArg arg)
		{
			return new BurocratForm(client, arg);
		}
	}
	
	;
	
	public abstract BurocratField buildField(IClient client, IArg arg);
}
