package org.colcon.burocrat.client.form;

import java.util.Date;

import org.colcon.burocrat.api.client.IClient;
import org.colcon.burocrat.api.model.IArg;
import org.colcon.burocrat.api.model.IResponse;

import com.google.gwt.user.client.ui.HorizontalPanel;
import com.google.gwt.user.client.ui.Label;
import com.google.gwt.user.client.ui.ListBox;
import com.google.gwt.user.client.ui.VerticalPanel;
import com.google.gwt.user.datepicker.client.DateBox;

import org.colcon.burocrat.client.BurocratField;
import org.colcon.burocrat.client.utils.TimeUtil;

/**
 * 
 * A field for Burocrat to input dates
 * 
 * @author Jesse Freitas
 */
public class DateField extends BurocratField
{

	private VerticalPanel main;
	private DateBox dateChooser;
	private ListBox hourChooser;
	private ListBox minChooser;
	private ListBox AMPMChooser;

	public DateField(IClient client, IArg arg)
	{
		super(client, arg);
	}

	@Override
	public String getValue()
	{
		final int PM = 1;
		// final int AM = 0;
		Date d = dateChooser.getValue();
		if (d == null)
			return null;
		int hour;
		if (AMPMChooser.getSelectedIndex() == PM)
			hour = (hourChooser.getSelectedIndex() + 12);
		else
			hour = (hourChooser.getSelectedIndex());
		long toRtn = d.getTime() + (hour * TimeUtil.hour)
				+ ((minChooser.getSelectedIndex() * 5 * TimeUtil.minute));
		return TimeUtil.dateToString(new Date(toRtn));
	}

	@Override
	public void setValue(String value)
	{
		//TODO: this does nothing, Jesse (commented to remove warning)
		// Date d = TimeUtil.stringToDate(value);
	}

	@Override
	public void init(IResponse data)
	{
		HorizontalPanel timePane = new HorizontalPanel();
		timePane.addStyleName("dateForm-Composite-TimePane");
		main.addStyleName("dateForm-Composite");

		dateChooser = new DateBox();
		dateChooser.setFormat(new DateBox.DefaultFormat(TimeUtil.noTimeFormat));
		hourChooser = new ListBox();
		hourChooser.setWidth("4em");

		minChooser = new ListBox();
		minChooser.setWidth("4em");

		AMPMChooser = new ListBox();
		AMPMChooser.setWidth("4em");

		for (int i = 0; i < 12; i++)
		{
			hourChooser.addItem((i + 1) + "");
		}
		for (int i = 0; i < 60; i += 5)
		{
			if (i < 10)
				minChooser.addItem("0" + i);
			else
				minChooser.addItem(i + "");
		}
		AMPMChooser.addItem("AM");
		AMPMChooser.addItem("PM");

		timePane.add(hourChooser);
		timePane.add(new Label(" : "));
		timePane.add(minChooser);
		timePane.add(new Label("  "));
		timePane.add(AMPMChooser);
		main.add(dateChooser);
		main.add(timePane);
		add(main);
	}

}
