package org.colcon.burocrat.client.list;

import org.colcon.burocrat.api.client.IClient;
import org.colcon.burocrat.api.model.IArg;
import org.colcon.burocrat.api.model.ICmd;
import org.colcon.burocrat.api.model.ICommand;
import org.colcon.burocrat.api.model.IItem;
import org.colcon.burocrat.api.model.IResponse;
import org.colcon.burocrat.client.CSS;
import org.colcon.burocrat.model.Arg;
import org.colcon.burocrat.model.Model;

import com.google.gwt.user.client.ui.HTML;
import com.google.gwt.user.client.ui.Widget;

/**
 * 
 * A subclass of BurocratList that serves as Burocrat's news feed
 * 
 * @author Dan Vegeto
 *
 */
public class NewsList extends BurocratList
{	
	public NewsList(IClient client, String path) 
	{
		super(client, path, new IArg[]{Arg.CREATED, Arg.TEXT}, null, new boolean[]{true, false});
	}

	public void init(IResponse data)
	{
		super.init(data);
		
		//TODO: pass this as a parameter to ListPanel
		removeRowStyle("clickable");
		removeRowStyle("list-row");
	}
	
	protected Widget buildGridCell(IItem item, IArg column)
	{
		if(!column.equals(Arg.TEXT))
			return super.buildGridCell(item, column);
		else
		{
			String agent = item.getArg(Arg.AGENT);
			String command = item.getArg(Arg.COMMAND);
			
			ICommand commandObj = Model.instance.parser().parseCommand(command);
			
			String text = getNewsText(agent, commandObj);
		
			HTML html = new HTML(text);
			html.setStyleName(CSS.LIST_CELL.getStyle());
			
			return html;
		}
	}
	
	private String getNewsText(String agent, ICommand command)
	{
		if(command == null)
			return "null";
		
		ICmd cmd = command.getCmd();
		
		if(cmd == null)
			return "null";
		
		String text = cmd.getNews(agent, command.getArgs());
		
		return replacePathsWithLinks(text);
	}
	
	protected void click(int row, int col)
	{
		if(row == 0)
			super.click(row, col);
	}
	
	private static String replacePathsWithLinks(String str)
	{
		return replacePathsWithLinks(str, true);
	}
	
	private static String replacePathsWithLinks(String str, boolean wrapWithHref)
	{
		String[] words = str.split(" ");
		
		String withLinks = "";
		
		for(int i = 0; i < words.length; i++)
		{
			if(words[i].startsWith("#") && words[i].length() > 1)
			{
				String href = words[i];
				String path = words[i].substring(1);
				String text = Model.instance.parser().pathToId(path);
				
				if(wrapWithHref)
					words[i] = "<a href=\"" + href + "\">" + text + "</a>";
				else
					words[i] = href;
			}
			
			withLinks += words[i] + ' ';
		}
		
		return withLinks.trim();
	}
}
