package org.colcon.burocrat.client.pages;

import org.colcon.burocrat.api.client.IClient;
import org.colcon.burocrat.api.client.IItemPageImpl;
import org.colcon.burocrat.api.model.ICommand;
import org.colcon.burocrat.api.model.IItem;
import org.colcon.burocrat.api.model.IItemType;
import org.colcon.burocrat.api.model.IResponse;
import org.colcon.burocrat.client.item.ItemPage;
import org.colcon.burocrat.client.ui.BurocratPage;
import org.colcon.burocrat.model.Arg;
import org.colcon.burocrat.model.Cmd;
import org.colcon.burocrat.model.Command;

import com.google.gwt.user.client.ui.Label;

/**
 * 
 * This is the page that is shown when the user navigates to a site path 
 * that is not implemented as a PageImpl. The client makes a Cmd.GET request
 * for the given path and then uses the corresponding ItemPageImpl to build
 * an ItemPage for that item.
 * 
 * @author Dan Vegeto
 *
 */
public class ItemRequestPage extends BurocratPage
{
	private String path;
	
	public ItemRequestPage(IClient client, String path) 
	{
		super(client);
		
		this.path = path;
	}
	
	public ICommand getRequest()
	{
		return new Command(
				Arg.CMD.put(Cmd.GET),
				Arg.PATH.put(path));
	}
	
	public void init(IResponse data)
	{
		super.init(data);
		
		if(data == null || data.getObject() == null || !(data.getObject() instanceof IItem))
		{
			add(new Label("item '" + path + "' not found"));
		}
		else
		{
			IItem item = (IItem) data.getObject();
			IItemType type = item.getType();

			IItemPageImpl itemPanelImpl = null;

			if(type != null)
				itemPanelImpl = getClient().getItemPageImpl(type.name());
			
			while(itemPanelImpl == null && type.parent() != null)
			{
				type = type.parent();
				itemPanelImpl = getClient().getItemPageImpl(type.name());
			}

			ItemPage itemPage = itemPanelImpl.buildItemPage(getClient(), item);
			
			getClient().show(itemPage);
		}
	}
}
