package org.colcon.burocrat.client.utils;

import java.io.UnsupportedEncodingException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

import org.colcon.burocrat.api.utils.StringUtil;

/**
 * This is a utility for accessing Gravatar icons and future image retrieval
 * operations
 * 
 * @author Jesse Freitas
 * 
 */
public class ImageUtil
{
	public final String INVALID = "404";
	public final String MM = "mm";
	public final String IDICON = "identicon";
	public final String MONSTER = "monsterid";
	public final String WAVATAR = "wavatar";
	public final String RETRO = "retro";
	public final String BLANK = "blank";

	/**
	 * Using an email, get the gravatar. If image is unavailable, use the
	 * default URI or Keyword from the ImageUtil Constants
	 * 
	 * @param email
	 *            the email address to retrieve the mapped gravatar.
	 * @param defaultKey
	 *            the Gravatar ImageUtil constant or URI for default image.
	 * @return The URI for the gravatar image requested.
	 */
	public static String getGravatar(String email, String defaultKey)
	{
		String URL = "http://www.gravatar.com/avatar/";
		email.trim();
		email.toLowerCase();
		URL += md5Hex(email);
		return URL + "?d=" + StringUtil.encodeURLSafe(defaultKey);
	}

	/**
	 * Using an email, get the gravatar. If image is unavailable, use the
	 * default URI or Keyword from the ImageUtil Constants
	 * 
	 * @param email
	 *            the email address to retrieve the mapped gravatar.
	 * @param defaultKey
	 *            the Gravatar ImageUtil constant or URI for default image.
	 * @size the size in pixels of the requested image
	 * @return The URI for the gravatar image requested.
	 */
	public static String getGravatar(String email, String defaultURL, int size)
	{
		if (size > 2048 || size < 0)
			size = 80;
		return getGravatar(email, defaultURL) + "&s=" + size;
	}

	/**
	 * The function to convert a byte array to hexidecimal. A Utility for
	 * {@code getGravatar()}
	 * 
	 * @param array
	 *            the array to convert
	 * @return the converted result in String form.
	 */
	public static String hex(byte[] array)
	{
		StringBuffer sb = new StringBuffer();
		for (int i = 0; i < array.length; ++i)
		{
			sb.append(Integer.toHexString((array[i] & 0xFF) | 0x100).substring(
					1, 3));
		}
		return sb.toString();
	}

	/**
	 * The function to convert a message into an MD5 hex hash. A Utility for
	 * {@code getGravatar()}
	 * 
	 * @param message
	 *            The String message to convert
	 * @return The converted String message
	 */
	public static String md5Hex(String message)
	{
		try
		{
			MessageDigest md = MessageDigest.getInstance("MD5");
			return hex(md.digest(message.getBytes("CP1252")));
		} catch (NoSuchAlgorithmException e)
		{
		} catch (UnsupportedEncodingException e)
		{
		}
		return null;
	}
}
