package org.colcon.burocrat.model;

import java.util.HashMap;
import java.util.Map;

import org.colcon.burocrat.api.model.IArg;
import org.colcon.burocrat.api.model.IArgObject;
import org.colcon.burocrat.api.model.IArgValue;

/**
 * 
 * A unit of data that can be represented as a map (a set of key-value pairs), 
 * such as an item, a command, or a link
 * 
 * @author Dan Vegeto
 *
 */
public class ArgObject implements IArgObject 
{
	private Map<IArg, String> map;
	
	public ArgObject(IArgValue... values)
	{
		map = new HashMap<IArg, String>();
		
		for(IArgValue value : values)
			if(value != null)
				map.put(value.getArg(), value.getValue());
	}
	
	public ArgObject(Map<IArg, String> map)
	{
		this.map = map;
	}
	
	public Map<IArg, String> getArgs()
	{
		return map;
	}
	
	public IArg[] getArgKeys()
	{
		return map.keySet().toArray(new IArg[0]);
	}
	
	public String getArg(IArg key)
	{
		return map.get(key);
	}
	
	public boolean hasArg(IArg key)
	{
		return map.get(key) != null;
	}
	
	public void setArg(IArg key, String value)
	{
		if(value == null)
			map.remove(key);
		else
			map.put(key, value);
	}
	
	public String toString()
	{
		return Model.instance.parser().composeArgs(getArgs());
	}
	
	public boolean equals(Object obj)
	{
		return obj instanceof IArgObject && 
				getArgs().equals(((IArgObject) obj).getArgs());
	}
}
