package org.colcon.burocrat.model;

import java.util.Date;
import java.util.Map;

import org.colcon.burocrat.api.model.IArg;
import org.colcon.burocrat.api.model.IArgValue;
import org.colcon.burocrat.api.model.IItem;
import org.colcon.burocrat.api.model.IItemType;

/**
 * This is an object representation of an item, 
 * which is a unit of data in the form of a map
 * of IArg to String.
 * 
 * @author Dan Vegeto
 *
 */
public class Item extends ArgObject implements IItem
{	
	public Item(IArgValue... values)
	{
		super(values);
	}
	
	public Item(Map<IArg, String> map)
	{
		super(map);
	}
	
	public String getId()
	{
		return getArg(Arg.ID);
	}

	public String getParent()
	{
		return getArg(Arg.PARENT);
	}
	
	public String getCreationTime()
	{
		return getArg(Arg.CREATED);
	}
	
	public String getAccessTime()
	{
		return getArg(Arg.ACCESSED);
	}
	
	public String getModificationTime()
	{
		return getArg(Arg.MODIFIED);
	}
	
	public IItemType getType()
	{
		String type = getArg(Arg.TYPE);
		
		if(type == null)
			return null;
		
		return Model.instance.getItemType(type);
	}
	
	public IItem[] getInitItems()
	{
		if(getType() != null)
			return getType().getInitItems(this);
		
		return new IItem[0];
	}
	
	public String getPath()
	{
		if(getParent() == null || getParent().equals(Constants.ROOT))
			return getId();
		
		return Model.instance.parser().composePath(getParent(), getId());
	}
	
	public boolean isPublic()
	{
		return hasArg(Arg.PUBLIC) && getArg(Arg.PUBLIC).equals(Boolean.TRUE.toString());
	}
	
	public boolean isRoot()
	{
		return getParent() == null || getParent().equals(Constants.ROOT);
	}
	
	public void init()
	{
		if(getType() != null)
			getType().init(this);
	}
	
	public void access()
	{
		setArg(Arg.ACCESSED, Long.toString(new Date().getTime()));
	}
	
	public void modify()
	{
		setArg(Arg.MODIFIED, Long.toString(new Date().getTime()));
	}
}
