package org.colcon.burocrat.model;

import org.colcon.burocrat.api.model.IItem;
import org.colcon.burocrat.api.model.IResponse;
import org.colcon.burocrat.api.model.IResponseType;

/**
 * 
 * This is a representation of a server response, 
 * which is passed into the async callback method 
 * after a command has been executed
 * 
 * @author Dan Vegeto
 *
 */
public class Response implements IResponse 
{
	private IResponseType type;
	private String message;
	
	public Response()
	{
		this(ResponseType.DID_NOTHING);
	}
	
	public Response(IResponseType type)
	{
		this(type, "");
	}
	
	public Response(boolean succeeded)
	{
		this(succeeded, "");
	}
	
	public Response(String message)
	{
		this(ResponseType.MESSAGE, message);
	}
	
	public Response(IItem item)
	{
		this(ResponseType.ITEM, item.toString());
	}
	
	public Response(IItem[] items)
	{
		this(ResponseType.ITEM_LIST, Model.instance.parser().composeItemArray(items));
	}
	
	public Response(boolean succeeded, String message)
	{
		this((succeeded ? ResponseType.SUCCEEDED : ResponseType.FAILED), message);
	}
	
	public Response(IResponseType type, String message)
	{
		this.type = type;
		this.message = message;
	}
	
	public IResponseType getType() 
	{
		return type;
	}

	public String getMessage() 
	{
		return message;
	}

	public Object getObject() 
	{
		return type.parseObject(getMessage());
	}
	
	public boolean isSuccess()
	{
		return type.equals(ResponseType.SUCCEEDED);
	}
	
	public String toString()
	{
		return Model.instance.parser().composeResponse(this);
	}
}
