package org.colcon.burocrat.server;

import org.colcon.burocrat.api.model.ICommand;
import org.colcon.burocrat.api.model.IItem;
import org.colcon.burocrat.api.server.IAuthenticator;
import org.colcon.burocrat.model.Arg;
import org.colcon.burocrat.model.Constants;
import org.colcon.burocrat.model.ItemType;

/**
 * 
 * This class is responsible for the site's security functionality, 
 * including user credential authentication and permission checking
 * 
 * @author Dan Vegeto
 *
 */
public class Authenticator implements IAuthenticator 
{
	public boolean authenticate(String id, String password)
	{
		if(id == null)
			return false;
		
		// cannot authenticate as guest
		if(id.equals(Constants.GUEST))
			return false;
		
		// path = "users/" + agent
		String path = ItemType.USER.getInstancePath(id);
		
		IItem user = Server.instance.get(path);
		
		if(user == null)
			return false;
		
		// email must be confirmed
		if(!Boolean.valueOf(user.getArg(Arg.EMAIL_CONFIRMED)))
			return false;
		
		String encrypted = user.getArg(Arg.PASSWORD);
		
		if(encrypted == null)
			return false;
		
		return Server.instance.encryptor().check(password, encrypted);
	}
	
	public boolean hasPermission(String agent, ICommand command)
	{
		return true;
	}
}
