package org.colcon.burocrat.server;

import java.util.Properties;

import javax.mail.Message;
import javax.mail.MessagingException;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.internet.AddressException;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;

import org.colcon.burocrat.api.server.IEmailer;

/**
 * This class is responsible for all email functionality
 * 
 * @author Dan Vegeto
 *
 */
public class Emailer implements IEmailer
{	
	private String
	
		subjectTag,
		sendAddress,
		emailFooter;
	
	public Emailer()
	{
		this(
				"[burocrat]", "colcongress@cc-burocrat.appspotmail.com", 
				"<p>This email was sent automatically by <a href=\"burocrat.org\">burocrat.org</a></p>" +
				"<p>Please email us at <a href=\"mailto:colcongress@gmail.com\">colcongress@gmail.com</a></p>"
		);
	}
	
	public Emailer(String subjectTag, String sendAddress, String emailFooter)
	{
		this.subjectTag = subjectTag;
		this.sendAddress = sendAddress;
		this.emailFooter = emailFooter;
	}
	
	public boolean send(String to, String subject, String text)
	{
		return send(sendAddress, to, subject, text);
	}
	
	public boolean send(String from, String to, String subject, String text)
	{		
		if(emailFooter != null)
			text += "<p>" + emailFooter + "</p>";
		
		try 
		{
			Properties props = new Properties();
		    Session mailSession = Session.getDefaultInstance(props, null);    
		    Message msg = new MimeMessage(mailSession);
		    msg.setFrom(new InternetAddress(sendAddress));
		    msg.addRecipient(Message.RecipientType.TO, new InternetAddress(to));
		    msg.setSubject(subjectTag + ' ' + subject);
		    msg.setContent(text, "text/html");
		    Transport.send(msg);
		    
		    return true;
		}
		catch (AddressException e)
		{
			e.printStackTrace();
			return false;
		}
		catch (MessagingException e)
		{
			e.printStackTrace();
			return false; 
		}
	}
}
